#
# spec file for package cpprest
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define major 2
%define minor 10
Name:           cpprest
Version:        2.10.2
Release:        lp150.1.1
Summary:        C++ REST library
# main: MIT (license.txt)
# Websocket++: BSD-3-Clause (ThirdPartyNotices.txt)
# base64/base64.hpp: Zlib (ThirdPartyNotices.txt)
# sha1/sha1.hpp: BSD-3-Clause (ThirdPartyNotices.txt)
# common/md5.hpp: Zlib (ThirdPartyNotices.txt)
# utf8_validation.hpp: MIT (ThirdPartyNotices.txt)
License:        MIT AND BSD-3-Clause AND Zlib
Group:          Development/Libraries/C and C++
Url:            https://github.com/Microsoft/cpprestsdk
Source:         https://github.com/Microsoft/cpprestsdk/archive/v%{version}.tar.gz#/cpprestsdk-%{version}.tar.gz
BuildRequires:  cmake >= 3.0
BuildRequires:  gcc-c++
BuildRequires:  openssl-devel >= 1.0
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_atomic-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_random-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
%else
BuildRequires:  boost-devel >= 1.55
%endif

%description
The C++ REST SDK is a Microsoft project for cloud-based client-server
communication in native code using a modern asynchronous C++ API design. This
project aims to help C++ developers connect to and interact with services.

Also known as Casablanca.

%package -n libcpprest%{major}_%{minor}
Summary:        C++ Rest library
Group:          System/Libraries

%description -n libcpprest%{major}_%{minor}
The C++ REST SDK is a Microsoft project for cloud-based client-server
communication in native code using a modern asynchronous C++ API design. This
project aims to help C++ developers connect to and interact with services.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       libcpprest%{major}_%{minor} = %{version}

%description devel
The C++ REST SDK is a Microsoft project for cloud-based client-server
communication in native code using a modern asynchronous C++ API design. This
project aims to help C++ developers connect to and interact with services.

Development files.

%prep
%setup -q -n cpprestsdk-%{version}

%build
%cmake \
	-DCMAKE_BUILD_TYPE=Release \
%ifarch ppc ppc64 ppc64le aarch64 %{arm}
	-DCMAKE_CXX_FLAGS:STRING="%{optflags} -Wno-error=attributes -Wno-error=type-limits -Wno-error=cast-align -Wno-error=deprecated-declarations" \
%endif
	../Release
make %{?_smp_mflags}

%install
mkdir -p %{buildroot}%{_includedir}
cp -r Release/include/* %{buildroot}%{_includedir}/
install -d -m 755 %{buildroot}%{_libdir}
chmod -x %{buildroot}%{_includedir}/cpprest/oauth1.h
cp build/Binaries/libcpprest.so.%{major}.%{minor} %{buildroot}%{_libdir}/
ln -sf libcpprest.so.%{major}.%{minor} %{buildroot}%{_libdir}/libcpprest.so

# create a pkgconfig file
install -d %{buildroot}%{_libdir}/pkgconfig
cat << EOF > %{buildroot}%{_libdir}/pkgconfig/%{name}.pc
prefix=%{_prefix}
exec_prefix=%{_prefix}
libdir=%{_libdir}
includedir=%{_includedir}

Name: %{name}
Description: cloud-based client-server communication
URL: %{url}
Version: %{version}
Libs: -L%{_libdir} -lcpprest
Cflags: -I%{_includedir}/cpprest -I%{_includedir}/pplx
EOF

%post -n libcpprest%{major}_%{minor} -p /sbin/ldconfig
%postun -n libcpprest%{major}_%{minor} -p /sbin/ldconfig

%files -n libcpprest%{major}_%{minor}
%doc CONTRIBUTORS.txt license.txt ThirdPartyNotices.txt
%{_libdir}/libcpprest.so.%{major}.%{minor}

%files devel
%doc CONTRIBUTORS.txt license.txt
%{_includedir}/%{name}
%{_includedir}/pplx
%{_libdir}/libcpprest.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Thu Mar 22 2018 astieger@suse.com
- update to 2.10.2:
  * Fix an issue where requests sent via authenticated proxies
    could not be successfully redirected from one domain to another
  * Add http_listener configuration for the backlog, the maximum
    length of the queue of pending connections on the port
  * Make it possible to set the user agent for websockets
  * Add support for retrieving HTTP version of a request in HTTP
    listener
  * various language/compiler fixes
  * drop upstreamed/unneeded patches:
    cpprest-2.10.1-srand-boost-1.66.patch
    cpprest-2.10.1-threadpool-boost-1.66.patch
* Thu Mar 22 2018 guillaume.gardet@opensuse.org
- Update _constraint file since we needs more memory
* Mon Jan  1 2018 antoine.belvire@opensuse.org
- Update to version 2.10.1:
  * Improve CMake generation of UWP binaries.
  * Fix regression in CMake versions supported. As listed in the
    main CMakeLists.txt, we intend to only require 3.0.
  * Mirror changes in the main PPL sources to
    Concurrency::details::do_while(), which yield a significant
    compiler throughput improvement on MSVC.
  * Fix issues under /permissive-, an on-by-default flag for new
    projects in VS2017 15.5.
- Fix build with Boost 1.66:
  * Add cpprest-2.10.1-srand-boost-1.66.patch.
  * Add cpprest-2.10.1-threadpool-boost-1.66.patch.
* Tue Dec  5 2017 i@marguerite.su
- add a pkgconfig file, fix boo#1068836
* Thu Nov 16 2017 astieger@suse.com
- cpprest 2.10.0:
  * build system fixes:
    + build system updates
    + cmake 3.0 required
  * Fix static library builds of test_runner on non-Windows platforms
    + compatibility fixes:
    + Improve compatibility with glibc 2.26
    + Improve compatibility with clang on Linux
    + Improve compatibility with icc 17.0
    + Improve compatibility with openssl 1.1.0
    + Fix building with LibreSSL
  * Fix several race conditions and memory leaks in the ASIO http_client
  * Fix process termination bug around certain exceptional cases in all http_clients
  * Add all remaining official HTTP status codes to http::status_codes
  * Add convenience wrappers json::value::has_T_field(T) for inspecting object values
  * Fix a race condition in the ASIO client during header parsing
  * Fix error when handling responses of type NoContent, NotModified, or from 100 to 199
  * Enable specifying the User Agent used in OAuth2 requests
  * Add http_request::get_remote_address() to expose the client's IP address for http_listener
  * Fix a bug in the ASIO http_client where the proxy is passed the same credentials as the target host
  * Make uri_builder::to_string() and uri_builder::to_uri() const
  * Add handling for the host wildchar + to the ASIO http_listener
  * Handle malformed URL requests to the ASIO http_listener instead of crashing
  * Fix a race condition in the websocketpp websocket_client
  * Fix several races in the ASIO http_listener which result in memory leaks or use after free of the connection objects
  * Add http_client_config::set_nativesessionhandle_options() which enables customization of the session handle on Windows Desktop
  * Improve UTF8/16 conversions from 6s per 1MB to 3s per 1GB (2000x improvement)
  * Enable limited IPv6 support to http_client and http_server, depending on the underlying platform
  * Fix a bug in base64 encoding that previously read beyond the input array, causing segfaults/AVs
  * Add compression support (deflate and gzip) for ASIO http_clients based on Zlib
  * Fix a memory leak in the UWP http_client when processing headers
  * Fix inappropriate handling of certain connections errors in the ASIO http_listener
- drop upstreamed or obsolete patches:
  * cpprest-pthread.patch
  * cpprestsdk-2.9.1-Fix-build-error-with-glibc-2.26-xlocale.h.patch
* Wed Aug 30 2017 astieger@suse.com
- fix build with glibc 2.26, adding
  cpprestsdk-2.9.1-Fix-build-error-with-glibc-2.26-xlocale.h.patch
* Thu Feb  2 2017 astieger@suse.com
- cpprest 2.9.1:
  * All embedded licenses changed to MIT
  * Update license header to reflect third party embedded code
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sun Oct 30 2016 astieger@suse.com
- cpprest 2.9.0:
  * Work around SSL compression methods memory leak in ASIO.
  * Fix header reading on linux listener using HTTPS.
  * Add support for basic authentication.
  * honour http_proxy env-variable.
  * Update to include access control allow origin.
  * Switched license from Apache 2.0 to MIT
* Mon Apr  4 2016 astieger@suse.com
- cpprest 2.8.0:
  * oauth: add more proxy support
  * http_client: Add TLS extension SNI for boost asio based http_client
  * http_client: allow specifying a host header in http requests.
  * http_client: add HTTP and HTTPS client proxy support
  * fix a bug where http_client_asio took forever to cancel.
* Wed Dec  2 2015 mpluskal@suse.com
- Update to 2.7.0
  * see https://github.com/Microsoft/cpprestsdk/releases for full
    list of changes
- Update project and download url
* Tue Jul  7 2015 schwab@suse.de
- Ignore cdecl warning also on arm
* Sun Jun 28 2015 astieger@suse.com
- fix architecture builds
* Wed Jun 24 2015 idonmez@suse.com
- Add cpprest-pthread.patch to fix unit test linking
* Fri Jun 12 2015 astieger@suse.com
- update to 2.6.0
  * Deprecate streambuf::putn API
  * File streams cleanup improvements
  * API detail improvements
  * Removed dependency on Boost.Locale and libiconv.
* Thu May 28 2015 astieger@suse.com
- fix files listed twice
* Thu May 28 2015 astieger@suse.com
- initial package
